RecursionPlan

Enum RecursionPlan 

pub enum RecursionPlan {
    IntCountdown,
    ListStructural,
    StringPosAdvance,
    MutualIntCountdown,
    MutualStringPosAdvance {
        rank: usize,
    },
    MutualSizeOfRanked {
        rank: usize,
        metric_param_index: usize,
    },
}
Proof-mode recursion support class for emitted Lean definitions.

Variants



IntCountdown

Single-function recursion where first Int parameter decreases by 1.



ListStructural

Single-function structural recursion on first List<_> parameter.



StringPosAdvance

Single-function recursion where first String stays the same and second Int parameter strictly advances (pos + k, k >= 1).



MutualIntCountdown

Mutual recursion group where first Int parameter decreases by 1 across SCC calls.



MutualStringPosAdvance

Mutual recursion group where first String is preserved and second Int either stays the same across rank-decreasing edges, or strictly advances.

Fields

rank: usize


MutualSizeOfRanked

Generic mutual recursion plan using sizeOf on a selected parameter, plus rank for same-parameter edges.

Fields

rank: usize
metric_param_index: usize