pub trait ArenaTypes:
Clone
+ Debug
+ 'static {
type Fn: Clone + Debug + FnValueName;
type Map: Clone + Debug + MapLike;
}Expand description
Trait that defines the function and map types used by the arena.
The arena stores function values and persistent maps, but their concrete types depend on the consumer (VM, WASM runtime, codegen, etc.).
Required Associated Types
Sourcetype Fn: Clone + Debug + FnValueName
type Fn: Clone + Debug + FnValueName
The function value type (e.g. FunctionValue in the VM).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.