Module http

Module http 

Functions

call
Returns Some(result) when name is owned by this service, None otherwise.
call_nv
Bridge: convert NanValue args to Value, call old implementation, convert result back.
effects
register
register_nv