pub fn tailcall_scc_components<'a>(fns: &[&'a FnDef]) -> Vec<Vec<&'a FnDef>>Expand description
Tail-call SCCs for mutual-trampoline codegen.
Returns only components with more than one function, sorted deterministically by the first function name in each SCC.