pub enum IndependenceMode {
Complete,
Cancel,
}Expand description
How independent products (?!) behave when one branch fails.
Variants
Complete
Wait for all branches to finish, then report one error.
Cancel
Signal siblings to stop as soon as one branch fails.